@@ -5,11 +5,10 @@ use warnings;
 
 use Class::Utils qw(set_params);
 use Cpanel::JSON::XS;
-use Error::Pure qw(err);
 use Getopt::Std;
 use Perl6::Slurp qw(slurp);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -82,7 +81,7 @@ sub _process_errors {
 						}
 						print "-- $id";
 						my $i = 0;
-						foreach my $param_key (keys %{$struct_hr}) {
+						foreach my $param_key (sort keys %{$struct_hr}) {
 							if ($i == 0) {
 								print ': ';
 							} else {
@@ -131,10 +130,12 @@ sub _process_report {
 	$self->{'_list'} = {};
 	foreach my $plugin (keys %{$self->{'_report'}}) {
 		if (! exists $self->{'_report'}->{$plugin}->{'checks'}) {
-			err "Doesn't exist key '".$self->{'_report'}->{$plugin}->{'checks'}." in plugin $plugin.";
+			print STDERR "Doesn't exist key 'checks' in plugin $plugin.";
+			return 1;
 		}
 		if (! exists $self->{'_report'}->{$plugin}->{'checks'}->{'not_valid'}) {
-			err "Doesn't exist key '".$self->{'_report'}->{$plugin}->{'checks'}->{'not_valid'}." in plugin $plugin.";
+			print STDERR "Doesn't exist key 'checks'->'not_valid' in plugin $plugin.";
+			return 1;
 		}
 		if (! exists $self->{'_list'}->{$plugin}) {
 			$self->{'_list'}->{$plugin} = {};
